summaryrefslogtreecommitdiff
path: root/src/mesa/main/rastpos.c
diff options
context:
space:
mode:
authorKristian Høgsberg <krh@bitplanet.net>2010-10-12 12:26:10 -0400
committerKristian Høgsberg <krh@bitplanet.net>2010-10-13 09:43:25 -0400
commitf9995b30756140724f41daf963fa06167912be7f (patch)
treebc34fd4db5eb9d2ad55968cb4e6e4e5a65df5a27 /src/mesa/main/rastpos.c
parent31aca27c08d6a385c595d34fe4ee06390bf5b0e8 (diff)
Drop GLcontext typedef and use struct gl_context instead
Diffstat (limited to 'src/mesa/main/rastpos.c')
-rw-r--r--src/mesa/main/rastpos.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/mesa/main/rastpos.c b/src/mesa/main/rastpos.c
index 75c67f2693..6f52f07dfa 100644
--- a/src/mesa/main/rastpos.c
+++ b/src/mesa/main/rastpos.c
@@ -545,10 +545,10 @@ _mesa_init_rastpos_dispatch(struct _glapi_table *disp)
* \param ctx GL context.
*
* Initialize the current raster position information in
* __GLcontextRec::Current, and adds the extension entry points to the
* dispatcher.
*/
-void _mesa_init_rastpos( GLcontext * ctx )
+void _mesa_init_rastpos( struct gl_context * ctx )
{
int i;
@@ -545,10 +545,10 @@ _mesa_init_rastpos_dispatch(struct _glapi_table *disp)
*
* Initialize the current raster position information in
- * __GLcontextRec::Current, and adds the extension entry points to the
+ * __struct gl_contextRec::Current, and adds the extension entry points to the
* dispatcher.
*/